aiomas — aiomas 0.2.0 documentation

# `aiomas`

This module provides easier access to the most used components of aiomas. This purely for your convenience and you can, of cource, also import everything from its actual submodule.

## Decorators

`expose`(func) | Decorator that enables RPC access to the decorated function.

## Functions

`async`(coro_or_future[, ignore_cancel]) | Run `asyncio.async()` with coro_or_future and set a callback that instantly raises all exceptions.

## Exceptions

`RemoteException`(origin, remote_traceback) | Wraps a traceback of an exception on the other side of a channel.

## Classes

`Agent`(container, name) | Base class for all agents.
`Container`(addr[, codec, clock]) | Container for agents.
`JSON`() | A `Codec` that uses JSON to encode and decode messages.
`MsgPack`() | A `Codec` that uses msgpack to encode and decode messages.
`AsyncioClock`() | `asyncio` based real-time clock.
`ExternalClock`(utc_start[, init_time]) | A clock that can be set by external process in order to synchronize it with other systems.